<?php
//
// ZoneMinder web Argentinian Spanish language file, $Date: 2005/03/16 17:38:37 $, $Revision: 1.8 $
// Copyright (C) 2003, 2004, 2005  Philip Coombes
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//

// ZoneMinder Spanish 'Argentina' Translation by Fernando Diaz.

// Simple String Replacements
$zmSlang24BitColour          = 'Color 24 bits';
$zmSlang8BitGrey             = 'Grises 8 bits';
$zmSlangActual               = 'Actual';
$zmSlangAddNewControl        = 'Add New Control';
$zmSlangAddNewMonitor        = 'Agregar Nuevo Monitor';
$zmSlangAddNewUser           = 'Agregar Nuevo Usuario';
$zmSlangAddNewZone           = 'Agregar Nueva Zona';
$zmSlangAlarm                = 'Alarma';
$zmSlangAlarmBrFrames        = 'Alarma<br/>Cuadros';
$zmSlangAlarmFrameCount      = 'Alarm Frame Count';
$zmSlangAlarmFrame           = 'Cuadro Alarma';
$zmSlangAlarmLimits          = 'Alarm Limits';
$zmSlangAlarmPx              = 'Alarm Px';
$zmSlangAlert                = 'Alerta';
$zmSlangAll                  = 'Todo';
$zmSlangApply                = 'Aplicar';
$zmSlangApplyingStateChange  = 'Aplicar Cambio Estado';
$zmSlangArchArchived         = 'Solo Archivados';
$zmSlangArchive              = 'Archivar';
$zmSlangArchUnarchived       = 'Solo Sin Archivar';
$zmSlangAttrAlarmFrames      = 'Alarm Frames';
$zmSlangAttrArchiveStatus    = 'Estado Archivo';
$zmSlangAttrAvgScore         = 'Puntaje Prom.';
$zmSlangAttrCause            = 'Cause';
$zmSlangAttrDate             = 'Fecha';
$zmSlangAttrDateTime         = 'Fecha/Hora';
$zmSlangAttrDiskBlocks       = 'Disk Blocks';
$zmSlangAttrDiskPercent      = 'Disk Percent';
$zmSlangAttrDuration         = 'Duracin';
$zmSlangAttrFrames           = 'Cuadros';
$zmSlangAttrId               = 'Id';
$zmSlangAttrMaxScore         = 'Puntaje Mximo';
$zmSlangAttrMonitorId        = 'Monitor Id';
$zmSlangAttrMonitorName      = 'Nombre Monitor';
$zmSlangAttrMontage          = 'Cmara Mltiple';
$zmSlangAttrName             = 'Name';
$zmSlangAttrTime             = 'Hora';
$zmSlangAttrTotalScore       = 'Puntaje Total';
$zmSlangAttrWeekday          = 'Da Semana';
$zmSlangAutoArchiveEvents    = 'Archivar todos los eventos';
$zmSlangAuto                 = 'Auto';
$zmSlangAutoDeleteEvents     = 'Borrar todos los eventos';
$zmSlangAutoEmailEvents      = 'Mandar un mail de todos los eventos';
$zmSlangAutoExecuteEvents    = 'Ejecutar un comando en las coincidencias';
$zmSlangAutoMessageEvents    = 'Mandar un mensaje de los eventos';
$zmSlangAutoUploadEvents     = 'Subir los eventos que coincidan';
$zmSlangAvgBrScore           = 'Punt.<br/>Promedio';
$zmSlangBadNameChars         = 'Los nombres pueden contener solamente caracteres alfanumricos ms el guin y la raya';
$zmSlangBandwidth            = 'Velocidad';
$zmSlangBlobPx               = 'Blob Px';
$zmSlangBlobs                = 'Blobs';
$zmSlangBlobSizes            = 'Blob Sizes';
$zmSlangBrightness           = 'Brillo';
$zmSlangBuffers              = 'Buffers';
$zmSlangCanAutoFocus         = 'Can Auto Focus';
$zmSlangCanAutoGain          = 'Can Auto Gain';
$zmSlangCanAutoIris          = 'Can Auto Iris';
$zmSlangCanAutoWhite         = 'Can Auto White Bal.';
$zmSlangCanAutoZoom          = 'Can Auto Zoom';
$zmSlangCancel               = 'Cancelar';
$zmSlangCancelForcedAlarm    = 'Cancelar&nbsp;Alarma&nbsp;Forzada';
$zmSlangCanFocusAbs          = 'Can Focus Absolute';
$zmSlangCanFocus             = 'Can Focus';
$zmSlangCanFocusCon          = 'Can Focus Continuous';
$zmSlangCanFocusRel          = 'Can Focus Relative';
$zmSlangCanGainAbs           = 'Can Gain Absolute';
$zmSlangCanGain              = 'Can Gain ';
$zmSlangCanGainCon           = 'Can Gain Continuous';
$zmSlangCanGainRel           = 'Can Gain Relative';
$zmSlangCanIrisAbs           = 'Can Iris Absolute';
$zmSlangCanIris              = 'Can Iris';
$zmSlangCanIrisCon           = 'Can Iris Continuous';
$zmSlangCanIrisRel           = 'Can Iris Relative';
$zmSlangCanMoveAbs           = 'Can Move Absolute';
$zmSlangCanMove              = 'Can Move';
$zmSlangCanMoveCon           = 'Can Move Continuous';
$zmSlangCanMoveDiag          = 'Can Move Diagonally';
$zmSlangCanMoveMap           = 'Can Move Mapped';
$zmSlangCanMoveRel           = 'Can Move Relative';
$zmSlangCanPan               = 'Can Pan' ;
$zmSlangCanReset             = 'Can Reset';
$zmSlangCanSetPresets        = 'Can Set Presets';
$zmSlangCanSleep             = 'Can Sleep';
$zmSlangCanTilt              = 'Can Tilt';
$zmSlangCanWake              = 'Can Wake';
$zmSlangCanWhiteAbs          = 'Can White Bal. Absolute';
$zmSlangCanWhiteBal          = 'Can White Bal.';
$zmSlangCanWhite             = 'Can White Balance';
$zmSlangCanWhiteCon          = 'Can White Bal. Continuous';
$zmSlangCanWhiteRel          = 'Can White Bal. Relative';
$zmSlangCanZoomAbs           = 'Can Zoom Absolute';
$zmSlangCanZoom              = 'Can Zoom';
$zmSlangCanZoomCon           = 'Can Zoom Continuous';
$zmSlangCanZoomRel           = 'Can Zoom Relative';
$zmSlangCaptureHeight        = 'Captura Alto';
$zmSlangCapturePalette       = 'Captura Paleta';
$zmSlangCaptureWidth         = 'Captura Ancho';
$zmSlangCause                = 'Cause';
$zmSlangCheckAll             = 'Marcar Todo';
$zmSlangCheckMethod          = 'Alarm Check Method';
$zmSlangChooseFilter         = 'Elegir Filtro';
$zmSlangClose                = 'Cerrar';
$zmSlangColour               = 'Color';
$zmSlangCommand              = 'Command';
$zmSlangConfig		     = 'Config.';
$zmSlangConfiguredFor        = 'Configurado Para';
$zmSlangConfirmPassword      = 'Confirmar Contrasea';
$zmSlangConjAnd              = 'y';
$zmSlangConjOr               = 'o';
$zmSlangConsole              = 'Consola';
$zmSlangConsole              = 'Console'; 
$zmSlangContactAdmin         = 'Contacte el Administrador para detalles.';
$zmSlangContinue             = 'Continue';
$zmSlangContrast             = 'Contraste';
$zmSlangControlAddress       = 'Control Address';
$zmSlangControlCap           = 'Control Capability';
$zmSlangControlCaps          = 'Control Capabilities';
$zmSlangControl              = 'Control';
$zmSlangControlDevice        = 'Control Device';
$zmSlangControllable         = 'Controllable';
$zmSlangControlType          = 'Control Type';
$zmSlangCycle                = 'Cycle';
$zmSlangCycleWatch           = 'Cycle Watch';
$zmSlangDay                  = 'Da';
$zmSlangDeleteAndNext        = 'Borrar &amp; Prximo';
$zmSlangDeleteAndPrev        = 'Borrar &amp; Anterior';
$zmSlangDelete               = 'Borrar';
$zmSlangDeleteSavedFilter    = 'Borrar Filtro Guardado';
$zmSlangDescription          = 'Descripcin';
$zmSlangDeviceChannel        = 'Canal';
$zmSlangDeviceFormat         = 'Seal (0=PAL,1=NTSC etc)';
$zmSlangDeviceNumber         = 'Fuente (/dev/video?)';
$zmSlangDimensions           = 'Dimensiones';
$zmSlangDisk                 = 'Disco';
$zmSlangDuration             = 'Duracin';
$zmSlangEdit                 = 'Editar';
$zmSlangEmail                = 'Email';
$zmSlangEnabled              = 'Habilitado';
$zmSlangEnterNewFilterName   = 'Ingresar Nuevo Nombre De Filtro';
$zmSlangErrorBrackets        = 'Error, Revisar si tiene la misma cantidad de parntesis de apertura';
$zmSlangError                = 'Error';
$zmSlangErrorValidValue      = 'Error, Revisar si los trminos tienen nombres validos';
$zmSlangEtc                  = 'etc';
$zmSlangEvent                = 'Evento';
$zmSlangEventFilter          = 'Filtro de Evento';
$zmSlangEventId              = 'Event Id';
$zmSlangEventName            = 'Event Name';
$zmSlangEventPrefix          = 'Event Prefix';
$zmSlangEvents               = 'Eventos';
$zmSlangExclude              = 'Excluir';
$zmSlangFar                  = 'Far';
$zmSlangFeed                 = 'Vista';
$zmSlangFilterPx             = 'Filtro Px';
$zmSlangFirst                = 'Primero';
$zmSlangFocus                = 'Focus';
$zmSlangForceAlarm           = 'Forzar&nbsp;Alarma';
$zmSlangFPS                  = 'fps';
$zmSlangFPSReportInterval    = 'Intervalo de Reporte FPS';
$zmSlangFrame                = 'Cuadro';
$zmSlangFrameId              = 'Id Cuadro';
$zmSlangFrameRate            = 'Velocidad del video';
$zmSlangFrames               = 'Cuadros';
$zmSlangFrameSkip            = 'Saltear Cuadro';
$zmSlangFTP                  = 'FTP';
$zmSlangFunc                 = 'Func';
$zmSlangFunction             = 'Funcin';
$zmSlangGain                 = 'Gain';
$zmSlangGenerateVideo        = 'Crear Video';
$zmSlangGeneratingVideo      = 'Creando Video';
$zmSlangGoToZoneMinder       = 'Ir a Zoneminder.com';
$zmSlangGrey                 = 'Gris';
$zmSlangGroups               = 'Groups';
$zmSlangHasFocusSpeed        = 'Has Focus Speed';
$zmSlangHasGainSpeed         = 'Has Gain Speed';
$zmSlangHasHomePreset        = 'Has Home Preset';
$zmSlangHasIrisSpeed         = 'Has Iris Speed';
$zmSlangHasPanSpeed          = 'Has Pan Speed';
$zmSlangHasPresets           = 'Has Presets';
$zmSlangHasTiltSpeed         = 'Has Tilt Speed';
$zmSlangHasTurboPan          = 'Has Turbo Pan';
$zmSlangHasTurboTilt         = 'Has Turbo Tilt';
$zmSlangHasWhiteSpeed        = 'Has White Bal. Speed';
$zmSlangHasZoomSpeed         = 'Has Zoom Speed';
$zmSlangHigh                 = 'Alta';
$zmSlangHighBW               = 'Alta&nbsp;B/W';
$zmSlangHome                 = 'Home';
$zmSlangHour                 = 'Hora';
$zmSlangHue                  = 'Saturacin';
$zmSlangId                   = 'Id';
$zmSlangIdle                 = 'Pasivo';
$zmSlangIgnore               = 'Ignorar';
$zmSlangImageBufferSize      = 'Tamao del Buffer de Imagen';
$zmSlangImage                = 'Imagen';
$zmSlangInclude              = 'Incluir';
$zmSlangIn                   = 'In';
$zmSlangInverted             = 'Invertido';
$zmSlangIris                 = 'Iris';
$zmSlangIsequalto            = 'Es igual a';
$zmSlangIsEqualTo            = 'is equal to'; 
$zmSlangLanguage             = 'Lenguaje';
$zmSlangLast                 = 'Ultimo';
$zmSlangLimitResultsPost     = 'Resultados;'; // This is used at the end of the phrase 'Limit to first N results only'
$zmSlangLimitResultsPre      = 'Solo los primeros'; // This is used at the beginning of the phrase 'Limit to first N results only'
$zmSlangLoad                 = 'Carga';
$zmSlangLocal                = 'Local';
$zmSlangLoggedInAs           = 'Registrado Como';
$zmSlangLoggingIn            = 'Ingresando';
$zmSlangLogin                = 'Ingresar';
$zmSlangLogout               = 'Salir';
$zmSlangLow                  = 'Baja';
$zmSlangLowBW                = 'Baja&nbsp;B/W';
$zmSlangMain                 = 'Main';
$zmSlangMan                  = 'Man';
$zmSlangManual               = 'Manual';
$zmSlangMark                 = 'Marca';
$zmSlangMaxBrScore           = 'Puntaje<br/>Max.';
$zmSlangMaxFocusRange        = 'Max Focus Range';
$zmSlangMaxFocusSpeed        = 'Max Focus Speed';
$zmSlangMaxFocusStep         = 'Max Focus Step';
$zmSlangMaxGainRange         = 'Max Gain Range';
$zmSlangMaxGainSpeed         = 'Max Gain Speed';
$zmSlangMaxGainStep          = 'Max Gain Step';
$zmSlangMaximumFPS           = 'Maximos FPS';
$zmSlangMaxIrisRange         = 'Max Iris Range';
$zmSlangMaxIrisSpeed         = 'Max Iris Speed';
$zmSlangMaxIrisStep          = 'Max Iris Step';
$zmSlangMax                  = 'Max';
$zmSlangMaxPanRange          = 'Max Pan Range';
$zmSlangMaxPanSpeed          = 'Max Pan Speed';
$zmSlangMaxPanStep           = 'Max Pan Step';
$zmSlangMaxTiltRange         = 'Max Tilt Range';
$zmSlangMaxTiltSpeed         = 'Max Tilt Speed';
$zmSlangMaxTiltStep          = 'Max Tilt Step';
$zmSlangMaxWhiteRange        = 'Max White Bal. Range';
$zmSlangMaxWhiteSpeed        = 'Max White Bal. Speed';
$zmSlangMaxWhiteStep         = 'Max White Bal. Step';
$zmSlangMaxZoomRange         = 'Max Zoom Range';
$zmSlangMaxZoomSpeed         = 'Max Zoom Speed';
$zmSlangMaxZoomStep          = 'Max Zoom Step';
$zmSlangMediumBW             = 'Media&nbsp;B/W';
$zmSlangMedium               = 'Media';
$zmSlangMinAlarmGeMinBlob    = 'Minimum alarm pixels should be greater than or equal to minimum blob pixels';
$zmSlangMinAlarmGeMinFilter  = 'Minimum alarm pixels should be greater than or equal to minimum filter pixels';
$zmSlangMinAlarmPixelsLtMax  = 'Minimum alarm pixels should be less than maximum alarm pixels';
$zmSlangMinBlobAreaLtMax     = 'Minimum blob area should be less than maximum blob area';
$zmSlangMinBlobsLtMax        = 'Minimum blobs should be less than maximum blobs';
$zmSlangMinFilterPixelsLtMax = 'Minimum filter pixels should be less than maximum filter pixels';
$zmSlangMinFocusRange        = 'Min Focus Range';
$zmSlangMinFocusSpeed        = 'Min Focus Speed';
$zmSlangMinFocusStep         = 'Min Focus Step';
$zmSlangMinGainRange         = 'Min Gain Range';
$zmSlangMinGainSpeed         = 'Min Gain Speed';
$zmSlangMinGainStep          = 'Min Gain Step';
$zmSlangMinIrisRange         = 'Min Iris Range';
$zmSlangMinIrisSpeed         = 'Min Iris Speed';
$zmSlangMinIrisStep          = 'Min Iris Step';
$zmSlangMinPanRange          = 'Min Pan Range';
$zmSlangMinPanSpeed          = 'Min Pan Speed';
$zmSlangMinPanStep           = 'Min Pan Step';
$zmSlangMinPixelThresLtMax   = 'Minimum pixel threshold should be less than maximum pixel threshold';
$zmSlangMinTiltRange         = 'Min Tilt Range';
$zmSlangMinTiltSpeed         = 'Min Tilt Speed';
$zmSlangMinTiltStep          = 'Min Tilt Step';
$zmSlangMinWhiteRange        = 'Min White Bal. Range';
$zmSlangMinWhiteSpeed        = 'Min White Bal. Speed';
$zmSlangMinWhiteStep         = 'Min White Bal. Step';
$zmSlangMinZoomRange         = 'Min Zoom Range';
$zmSlangMinZoomSpeed         = 'Min Zoom Speed';
$zmSlangMinZoomStep          = 'Min Zoom Step';
$zmSlangMisc                 = 'Otros';
$zmSlangMonitorIds           = 'Ids&nbsp;Monitor';
$zmSlangMonitor              = 'Monitor';
$zmSlangMonitors             = 'Monitores';
$zmSlangMontage              = 'Cmara Mltiple';
$zmSlangMonth                = 'Mes';
$zmSlangMove                 = 'Move';
$zmSlangMustBeGe             = 'Debe ser mayor o igual que';
$zmSlangMustBeLe             = 'Debe ser menor o igual que';
$zmSlangMustConfirmPassword  = 'Debe confirmar la contrasea';
$zmSlangMustSupplyPassword   = 'Debe ingresar una contrasea';
$zmSlangName                 = 'Nombre';
$zmSlangNear                 = 'Near';
$zmSlangNetwork              = 'Red';
$zmSlangNewGroup             = 'New Group';
$zmSlangNew                  = 'Nuevo';
$zmSlangNewPassword          = 'Nueva Contrasea';
$zmSlangNewState             = 'Nuevo Estado';
$zmSlangNewUser              = 'Nuevo Usuario';
$zmSlangNext                 = 'Siguiente';
$zmSlangNoFramesRecorded     = 'No hay movimientos grabados para este evento';
$zmSlangNoGroups             = 'No groups have been defined';
$zmSlangNoneAvailable        = 'Ninguno Disponible';
$zmSlangNone                 = 'Ninguno';
$zmSlangNo                   = 'No';
$zmSlangNormal               = 'Normal';
$zmSlangNoSavedFilters       = 'FiltrosNoGuardados';
$zmSlangNoStatisticsRecorded = 'No hay estadisticas guardadas para este evento/marco';
$zmSlangNumPresets           = 'Num Presets';
$zmSlangOpen                 = 'Open';
$zmSlangOpEq                 = 'igual que';
$zmSlangOpGtEq               = 'mayor o igual que';
$zmSlangOpGt                 = 'mayor que';
$zmSlangOpIn                 = 'En sistema';
$zmSlangOpLtEq               = 'menor o igual que';
$zmSlangOpLt                 = 'menor que';
$zmSlangOpMatches            = 'Coincide';
$zmSlangOpNe                 = 'distinto que';
$zmSlangOpNotIn              = 'No en sistema';
$zmSlangOpNotMatches         = 'No coincide';
$zmSlangOptionHelp           = 'Ayuda';
$zmSlangOptionRestartWarning = 'Estos cambios no se guardaran completamente\nmientras el sistema se ejecute. Cuando termine\nde realizar los cambios asegurese de\nreiniciar Zoneminder.';
$zmSlangOptions              = 'Opciones';
$zmSlangOrEnterNewName       = 'o agregue  nombre';
$zmSlangOrientation          = 'Orientacin';
$zmSlangOut                  = 'Out';
$zmSlangOverwriteExisting    = 'Sobreescribir Exitente';
$zmSlangPaged                = 'Paged';
$zmSlangPan                  = 'Pan';
$zmSlangPanTilt              = 'Pan/Tilt';
$zmSlangParameter            = 'Parametro';
$zmSlangPassword             = 'Contrasea';
$zmSlangPasswordsDifferent   = 'Las contraseas nueva y de confirmacion son diferentes';
$zmSlangPaths                = 'Enlaces';
$zmSlangPhoneBW              = 'Tel.&nbsp;B/N';
$zmSlangPhone                = 'Phone';
$zmSlangPixels               = 'pixels';
$zmSlangPlayAll              = 'Play All';
$zmSlangPleaseWait           = 'Espere por favor';
$zmSlangPostEventImageBuffer = 'Buffer Imagenes despues evento';
$zmSlangPreEventImageBuffer  = 'Buffer Imagenes antes evento';
$zmSlangPreset               = 'Preset';
$zmSlangPresets              = 'Presets';
$zmSlangPrev                 = 'Prev';
$zmSlangRate                 = 'Ritmo';
$zmSlangReal                 = 'Real';
$zmSlangRecord               = 'Registro';
$zmSlangRefImageBlendPct     = 'Reference Image Blend %ge';
$zmSlangRefresh              = 'Actualizar';
$zmSlangRemoteHostName       = 'Nombre Servidor Remoto';
$zmSlangRemoteHostPath       = 'Enlace Servidor Remoto';
$zmSlangRemoteHostPort       = 'Puerto Servidor Remoto';
$zmSlangRemoteImageColours   = 'Remote Image Colours';
$zmSlangRemote               = 'Remote';
$zmSlangRename               = 'Renombrar';
$zmSlangReplay               = 'Replay';
$zmSlangResetEventCounts     = 'Borrar Contador Eventos';
$zmSlangReset                = 'Reset';
$zmSlangRestarting           = 'Reiniciando';
$zmSlangRestart              = 'Reiniciar';
$zmSlangRestrictedCameraIds  = 'Id. Camara restringida';
$zmSlangReturnDelay          = 'Return Delay';
$zmSlangReturnLocation       = 'Return Location';
$zmSlangRotateLeft           = 'Rotar a la derecha';
$zmSlangRotateRight          = 'Rotar a la izquierda';
$zmSlangRunMode              = 'Metodo Ejecucion';
$zmSlangRunning              = 'Ejecutando';
$zmSlangRunState             = 'Estado de Ejecucin';
$zmSlangSaveAs               = 'Guardar Como';
$zmSlangSaveFilter           = 'Guardar Filtro';
$zmSlangSave                 = 'Guardar';
$zmSlangScale                = 'Escala';
$zmSlangScore                = 'Res.';
$zmSlangSecs                 = 'Seg';
$zmSlangSectionlength        = 'Longitud Seccin';
$zmSlangSelect               = 'Select';
$zmSlangServerLoad           = 'Carga Servidor';
$zmSlangSetLearnPrefs        = 'Set Learn Prefs'; // This can be ignored for now
$zmSlangSetNewBandwidth      = 'Nuevo Ancho de Banda';
$zmSlangSetPreset            = 'Set Preset';
$zmSlangSet                  = 'Set';
$zmSlangSettings             = 'Configuracion';
$zmSlangShowFilterWindow     = 'Abrir Filtro';
$zmSlangSleep                = 'Sleep';
$zmSlangSortAsc              = 'Asc';
$zmSlangSortBy               = 'Ordenar por';
$zmSlangSortDesc             = 'Desc';
$zmSlangSource               = 'Origen';
$zmSlangSourceType           = 'Tipo Origen';
$zmSlangSpeedHigh            = 'High Speed';
$zmSlangSpeedLow             = 'Low Speed';
$zmSlangSpeedMedium          = 'Medium Speed';
$zmSlangSpeed                = 'Speed';
$zmSlangSpeedTurbo           = 'Turbo Speed';
$zmSlangStart                = 'Iniciar';
$zmSlangState                = 'Estado';
$zmSlangStats                = 'Est.';
$zmSlangStatus               = 'Estado';
$zmSlangStepLarge            = 'Large Step';
$zmSlangStepMedium           = 'Medium Step';
$zmSlangStepNone             = 'No Step';
$zmSlangStepSmall            = 'Small Step';
$zmSlangStep                 = 'Step';
$zmSlangStills               = 'Fotos';
$zmSlangStop                 = 'Desactivar';
$zmSlangStopped              = 'Apagado';
$zmSlangStream               = 'Stream';
$zmSlangSubmit               = 'Submit';
$zmSlangSystem               = 'Sistema';
$zmSlangTele                 = 'Tele';
$zmSlangThumbnail            = 'Thumbnail';
$zmSlangTilt                 = 'Tilt';
$zmSlangTimeDelta            = 'Hora Delta';
$zmSlangTime                 = 'Hora';
$zmSlangTimestamp            = 'Etiqueta Hora';
$zmSlangTimeStamp            = 'Etiqueta Hora';
$zmSlangTimestampLabelFormat = 'Formato Etiqueta Hora';
$zmSlangTimestampLabelX      = 'Eje X Etiqueta Hora';
$zmSlangTimestampLabelY      = 'Eje Y Etiqueta Hora';
$zmSlangToday                = 'Today';
$zmSlangTools                = 'Herra.';
$zmSlangTotalBrScore         = 'Total<br/>puntuacin';
$zmSlangTrackDelay           = 'Track Delay';
$zmSlangTrackMotion          = 'Track Motion';
$zmSlangTriggers             = 'Gatillos';
$zmSlangTurboPanSpeed        = 'Turbo Pan Speed';
$zmSlangTurboTiltSpeed       = 'Turbo Tilt Speed';
$zmSlangType                 = 'Tipo';
$zmSlangUnarchive            = 'Desarchivar';
$zmSlangUnits                = 'Unidades';
$zmSlangUnknown              = 'Desconocido';
$zmSlangUpdateAvailable      = 'Una Actualizacin a ZoneMinder esta disponible';
$zmSlangUpdateNotNecessary   = 'No se requiere Actualizacin';
$zmSlangUseFilterExprsPost   = '&nbsp;filtrar&nbsp;sentencias'; // This is used at the end of the phrase 'use N filter expressions'
$zmSlangUseFilterExprsPre    = 'Utilizar&nbsp;'; // This is used at the beginning of the phrase 'use N filter expressions'
$zmSlangUseFilter            = 'Usar Filtro';
$zmSlangUsername             = 'Nombre';
$zmSlangUsers                = 'Usuarios';
$zmSlangUser                 = 'Usuario';
$zmSlangValue                = 'Valor';
$zmSlangVersionIgnore        = 'Ignore esta versin';
$zmSlangVersionRemindDay     = 'Recordar en 1 da';
$zmSlangVersionRemindHour    = 'Recordar en 1 hora';
$zmSlangVersionRemindNever   = 'No avizar de nuevas versiones';
$zmSlangVersionRemindWeek    = 'Recordar en 1 semana';
$zmSlangVersion              = 'Versin';
$zmSlangVideoGenFailed       = 'Fallo la creacion del video!';
$zmSlangVideoGenParms        = 'Parametros Generacion Video';
$zmSlangVideoSize            = 'Tamao Video';
$zmSlangVideo                = 'Video';
$zmSlangViewAll              = 'Ver Todo';
$zmSlangViewPaged            = 'View Paged';
$zmSlangView                 = 'Ver';
$zmSlangWake                 = 'Wake';
$zmSlangWarmupFrames         = 'Avisos Movimiento';
$zmSlangWatch                = 'Monitor';
$zmSlangWeb                  = 'Web';
$zmSlangWeek                 = 'Semana';
$zmSlangWhiteBalance         = 'White Balance';
$zmSlangWhite                = 'White';
$zmSlangWide                 = 'Wide';
$zmSlangX10ActivationString  = 'X10 Comando Activacin';
$zmSlangX10InputAlarmString  = 'X10 Comando Entrada Alarma';
$zmSlangX10OutputAlarmString = 'X10 Output Alarm String';
$zmSlangX10                  = 'X10';
$zmSlangYes                  = 'Si';
$zmSlangYouNoPerms           = 'No tiene permisos para acceder a este recurso.';
$zmSlangZoneAlarmColour      = 'Color Alarma (RGB)';
$zmSlangZoneAlarmThreshold   = 'Alarm Threshold (0-255)';
$zmSlangZoneFilterHeight     = 'Altura Filtro (pixels)';
$zmSlangZoneFilterWidth      = 'Ancho FIltro (pixels)';
$zmSlangZoneMaxAlarmedArea   = 'Maximo Area Alarma';
$zmSlangZoneMaxBlobArea      = 'Maximo Blob Area';
$zmSlangZoneMaxBlobs         = 'Maximo Blobs';
$zmSlangZoneMaxFilteredArea  = 'Maximo Area Filtrada';
$zmSlangZoneMaxPixelThres    = 'Maximum Pixel Threshold (0-255)';
$zmSlangZoneMaxX             = 'Maximo X (Derecha)';
$zmSlangZoneMaxY             = 'Maximo Y (Abajo)';
$zmSlangZoneMinAlarmedArea   = 'Minimo Area Alarma';
$zmSlangZoneMinBlobArea      = 'Minimum Blob Area';
$zmSlangZoneMinBlobs         = 'Minimum Blobs';
$zmSlangZoneMinFilteredArea  = 'Minimo Area Filtrada';
$zmSlangZoneMinPixelThres    = 'Minimum Pixel Threshold (0-255)';
$zmSlangZoneMinX             = 'Minimo X (Izquierda)';
$zmSlangZoneMinY             = 'Minimo Y (Arriba)';
$zmSlangZones                = 'Zonas';
$zmSlangZone                 = 'Zona';
$zmSlangZoom                 = 'Zoom';

// Complex replacements with formatting and/or placements, must be passed through sprintf
$zmClangCurrentLogin         = 'Usuario actual es \'%1$s\'';
$zmClangEventCount           = '%1$s %2$s';
$zmClangLastEvents           = 'Ultimo %1$s %2$s';
$zmClangLatestRelease        = 'The latest release is v%1$s, you have v%2$s.';
$zmClangMonitorCount         = '%1$s %2$s';
$zmClangMonitorFunction      = 'Monitor %1$s Funcion';
$zmClangRunningRecentVer     = 'You are running the most recent version of Zoneminder, v%s.';

// Variable arrays expressing plurality, see the zmVlang description above
$zmVlangEvent                = array( 0=>'Eventos', 1=>'Evento', 2=>'Eventos' );
$zmVlangMonitor              = array( 0=>'Monitores', 1=>'Monitor', 2=>'Monitores' );


function zmVlang( $lang_var_array, $count )
{
	krsort( $lang_var_array );
	foreach ( $lang_var_array as $key=>$value )
	{
		if ( abs($count) >= $key )
		{
			return( $value );
		}
	}
	die( 'Error, unable to correlate variable language string' );
}

?>
